/**
 * Extractor
 */

const pathTool = require('path');
const chalk = require('chalk');
const _ = require('lodash');
const ignore = require('ignore');
const { processParameters, scanFiles, verifyMessages } = require('../core/util');
const cwd = process.cwd();

let ig;

/**
 * Extract message from files in path
 * @param {{ path, targetExtensions,  excludeDirName }} options
 */
const extractToDetailArray = (options = {}) => {
  const params = processParameters('common', options);
  ig = ignore().add(_.get(params, 'ignore', []));
  const startPath = pathTool.join(cwd, params.path);
  // console.log(chalk.magenta(`================== Scaning ==================`));
  let messages = scanFiles(startPath, params, ig);

  if (verifyMessages(messages)) {
    // const exportPath = pathTool.join(cwd, _.get(params, 'exportPath', './'));
    messages = _.sortBy(messages, 'key');
    messages = _.uniqBy(messages, 'key');
    return messages;
  } else {
    console.error(chalk.red('Some key has different default message. Please fix them.'))
    return null;
  }

};


/**
 * Exreact as simple map
 * @param {{ path, targetExtensions,  excludeDirName }} options
 */
function extractToSimpleMap(options = {}) {
  const messages = extractToDetailArray(options);
  const map = {};
  (messages || []).forEach(item => {
    map[item.key] = item.targetDefaultMessage;
  });
  return map;
}

/**
 * Write extracted locale data to file
 * @param {{ path, targetExtensions,  excludeDirName, outputFilePath }} options
 * filePath: test/
 */
function write(options = {}) {
  const map = extractToSimpleMap(options);
  if (!fs.existsSync(filePath)) {
    fs.mkdirSync(filePath);
  }
  const filePath = options.options || 'src/locales/your_locale.json';
  fs.writeFileSync(filePath, JSON.stringify(map, null, 2)); 
}


module.exports = {
  extractToDetailArray,
  extractToSimpleMap,
  write,
  // TODO save to file
};